@@ -9,8 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 
-from __future__ import absolute_import, division, print_function
-
 import re
 from collections import OrderedDict
 from os.path import isfile, join, relpath
@@ -23,11 +21,7 @@ from strictyaml import Optional as Opt
 from strictyaml import Regex, Seq, Str, load
 
 from LbAPCommon import config
-
-try:
-    FileNotFoundError
-except NameError:
-    FileNotFoundError = IOError
+from LbAPCommon.linting.bk_paths import validate_bk_query
 
 RE_APPLICATION = r"^([A-Za-z]+/)+v\d+r\d+(p\d+)?"
 RE_JOB_NAME = r"^[a-zA-Z0-9][a-zA-Z0-9_\-]+$"
@@ -157,28 +151,69 @@ def parse_yaml(rendered_yaml):
     return data2
 
 
+def _normalise_filetype(prod_name, job_name, filetype):
+    filetype = filetype.upper()
+
+    errors = []
+    if len(filetype) >= 50:
+        errors += ["The filetype is excessively long"]
+    if re.findall(r"[0-9]{8}", filetype, re.IGNORECASE):
+        errors += ["It appears the event type is included"]
+    if re.findall(r"Mag(Up|Down)", filetype, re.IGNORECASE):
+        errors += ["It appears the magnet polarity is included"]
+    if re.findall(r"(^|[^0*9])201[125678]($|[^0*9])", filetype, re.IGNORECASE):
+        errors += ["It appears the data taking year is included"]
+
+    if errors:
+        _errors = "\n  * ".join(errors)
+        raise ValueError(
+            f"Output filetype {filetype} for {prod_name}/{job_name} is invalid "
+            f"as it appears to contain redundant information.\n\n"
+            f"  * {_errors}"
+        )
+    return filetype
+
+
 def validate_yaml(data, repo_root, prod_name):
-    # Ensure all values that cam be either a list or a string are lists of strings
-    for job_data in data.values():
-        for prop in ["output", "options", "inform"]:
-            if not isinstance(job_data[prop], list):
-                job_data[prop] = [job_data[prop]]
-        job_data["output"] = [s.upper() for s in job_data["output"]]
+    # Ensure all values that can be either a list or a string are lists of strings
+    for job_name, job_data in data.items():
+        try:
+            _validate_job_data(repo_root, prod_name, job_name, job_data)
+        except Exception as e:
+            raise ValueError(f"Failed to validate {job_name!r} with error {e!r}")
+
+
+def _validate_job_data(repo_root, prod_name, job_name, job_data):
+    # Normalise list/str fields to always be lists
+    for prop in ["output", "options", "inform"]:
+        if not isinstance(job_data[prop], list):
+            job_data[prop] = [job_data[prop]]
+
+    # Validate the input data
+    if "bk_query" in job_data["input"]:
+        validate_bk_query(job_data["input"]["bk_query"])
+
+    # Validate the output filetype
+    job_data["output"] = [
+        _normalise_filetype(prod_name, job_name, s) for s in job_data["output"]
+    ]
 
     # Normalise the options filenames
-    for job_data in data.values():
-        normalised_options = []
-        for fn in job_data["options"]:
-            if fn.startswith("$"):
-                normalised_options.append(fn)
-                continue
+    normalised_options = []
+    for fn in job_data["options"]:
+        if fn.startswith("$"):
+            normalised_options.append(fn)
+            continue
 
-            fn_normed = relpath(join(repo_root, fn), start=repo_root)
-            if fn_normed.startswith("../"):
-                raise ValueError("{} not found inside {}".format(fn, repo_root))
-            if not isfile(join(repo_root, prod_name, fn_normed)):
-                raise FileNotFoundError(isfile(join(repo_root, prod_name, fn_normed)))
-            normalised_options.append(
-                join("$ANALYSIS_PRODUCTIONS_BASE", prod_name, fn_normed)
+        fn_normed = relpath(join(repo_root, fn), start=repo_root)
+        if fn_normed.startswith("../"):
+            raise ValueError(f"{fn} not found inside {repo_root}")
+        if not isfile(join(repo_root, prod_name, fn_normed)):
+            raise FileNotFoundError(
+                f"Production {job_name!r} has a missing options file: "
+                f"{join(prod_name, fn_normed)!r}",
             )
-        job_data["options"] = normalised_options
+        normalised_options.append(
+            join("$ANALYSIS_PRODUCTIONS_BASE", prod_name, fn_normed)
+        )
+    job_data["options"] = normalised_options
