@@ -9,8 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 
-from __future__ import absolute_import, division, print_function
-
 from textwrap import dedent
 
 import pytest
@@ -35,7 +33,7 @@ def test_good_no_defaults():
     job_1:
         application: DaVinci/v45r3
         input:
-            bk_query: /some/query
+            bk_query: /MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
         output: FILETYPE.ROOT
         options:
             - options.py
@@ -47,7 +45,9 @@ def test_good_no_defaults():
     data = LbAPCommon.parse_yaml(rendered_yaml)
     assert len(data) == 1
     assert data["job_1"]["application"] == "DaVinci/v45r3"
-    assert data["job_1"]["input"] == {"bk_query": "/some/query"}
+    assert data["job_1"]["input"] == {
+        "bk_query": "/MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
+    }
     assert data["job_1"]["output"] == "FILETYPE.ROOT"
     assert data["job_1"]["options"] == ["options.py", "$VAR/a.py"]
     assert data["job_1"]["wg"] == "Charm"
@@ -75,7 +75,7 @@ def test_good_output_filetype_scalar(value, expected):
     job_1:
         application: DaVinci/v45r3
         input:
-            bk_query: /some/query
+            bk_query: /MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
         output: {value}
         options:
             - $VAR/a.py
@@ -92,7 +92,9 @@ def test_good_output_filetype_scalar(value, expected):
     assert data["job_1"]["output"] == expected
 
     assert data["job_1"]["application"] == "DaVinci/v45r3"
-    assert data["job_1"]["input"] == {"bk_query": "/some/query"}
+    assert data["job_1"]["input"] == {
+        "bk_query": "/MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
+    }
     assert data["job_1"]["options"] == ["$VAR/a.py"]
     assert data["job_1"]["wg"] == "Charm"
     assert data["job_1"]["automatically_configure"] is False
@@ -112,7 +114,7 @@ def test_good_with_defaults():
     job_1:
         application: DaVinci/v45r3
         input:
-            bk_query: "/some/query"
+            bk_query: "/MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
         output: FILETYPE.ROOT
         options:
             - options.py
@@ -120,7 +122,7 @@ def test_good_with_defaults():
     job_2:
         application: DaVinci/v44r0
         input:
-            bk_query: "/some/other/query"
+            bk_query: "/MC/2018/Beam6500GeV-2018-MagUp/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
         output: FILETYPE.ROOT
         options:
             - other_options.py
@@ -134,7 +136,9 @@ def test_good_with_defaults():
     assert len(data) == 2
 
     assert data["job_1"]["application"] == "DaVinci/v45r3"
-    assert data["job_1"]["input"] == {"bk_query": "/some/query"}
+    assert data["job_1"]["input"] == {
+        "bk_query": "/MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
+    }
     assert data["job_1"]["output"] == "FILETYPE.ROOT"
     assert data["job_1"]["options"] == ["options.py"]
     assert data["job_1"]["wg"] == "Charm"
@@ -143,7 +147,9 @@ def test_good_with_defaults():
     assert data["job_1"]["inform"] == ["name@example.com"]
 
     assert data["job_2"]["application"] == "DaVinci/v44r0"
-    assert data["job_2"]["input"] == {"bk_query": "/some/other/query"}
+    assert data["job_2"]["input"] == {
+        "bk_query": "/MC/2018/Beam6500GeV-2018-MagUp/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
+    }
     assert data["job_2"]["output"] == "FILETYPE.ROOT"
     assert data["job_2"]["options"] == ["other_options.py"]
     assert data["job_2"]["wg"] == "B2OC"
@@ -165,7 +171,7 @@ def test_good_all_turbo():
     job_1:
         application: DaVinci/v45r3
         input:
-            bk_query: "/some/query"
+            bk_query: "/MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
         output: FILETYPE.ROOT
         options:
             - options.py
@@ -173,7 +179,7 @@ def test_good_all_turbo():
     job_2:
         application: DaVinci/v44r0
         input:
-            bk_query: "/some/other/query"
+            bk_query: "/MC/2018/Beam6500GeV-2018-MagUp/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
         output: FILETYPE.ROOT
         options:
             - other_options.py
@@ -185,7 +191,7 @@ def test_good_all_turbo():
     job_3:
         application: DaVinci/v45r3
         input:
-            bk_query: "/some/query"
+            bk_query: "/MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
         output: FILETYPE.ROOT
         turbo: no
         options:
@@ -196,7 +202,9 @@ def test_good_all_turbo():
     assert len(data) == 3
 
     assert data["job_1"]["application"] == "DaVinci/v45r3"
-    assert data["job_1"]["input"] == {"bk_query": "/some/query"}
+    assert data["job_1"]["input"] == {
+        "bk_query": "/MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
+    }
     assert data["job_1"]["output"] == "FILETYPE.ROOT"
     assert data["job_1"]["options"] == ["options.py"]
     assert data["job_1"]["wg"] == "Charm"
@@ -205,7 +213,9 @@ def test_good_all_turbo():
     assert data["job_1"]["inform"] == ["name@example.com"]
 
     assert data["job_2"]["application"] == "DaVinci/v44r0"
-    assert data["job_2"]["input"] == {"bk_query": "/some/other/query"}
+    assert data["job_2"]["input"] == {
+        "bk_query": "/MC/2018/Beam6500GeV-2018-MagUp/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
+    }
     assert data["job_2"]["output"] == "FILETYPE.ROOT"
     assert data["job_2"]["options"] == ["other_options.py"]
     assert data["job_2"]["wg"] == "B2OC"
@@ -214,7 +224,9 @@ def test_good_all_turbo():
     assert data["job_2"]["inform"] == ["other@example.com"]
 
     assert data["job_3"]["application"] == "DaVinci/v45r3"
-    assert data["job_3"]["input"] == {"bk_query": "/some/query"}
+    assert data["job_3"]["input"] == {
+        "bk_query": "/MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
+    }
     assert data["job_3"]["output"] == "FILETYPE.ROOT"
     assert data["job_3"]["options"] == ["options.py"]
     assert data["job_3"]["wg"] == "Charm"
@@ -240,7 +252,7 @@ def test_good_some_turbo():
     job_1:
         application: DaVinci/v45r3
         input:
-            bk_query: "/some/query"
+            bk_query: "/MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
         output: FILETYPE.ROOT
         options:
             - options.py
@@ -248,7 +260,7 @@ def test_good_some_turbo():
     job_2:
         application: DaVinci/v44r0
         input:
-            bk_query: "/some/other/query"
+            bk_query: "/MC/2018/Beam6500GeV-2018-MagUp/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
         output: FILETYPE.ROOT
         options:
             - other_options.py
@@ -260,7 +272,7 @@ def test_good_some_turbo():
     job_3:
         application: DaVinci/v45r3
         input:
-            bk_query: "/some/query"
+            bk_query: "/MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
         output: FILETYPE.ROOT
         turbo: yes
         options:
@@ -271,7 +283,9 @@ def test_good_some_turbo():
     assert len(data) == 3
 
     assert data["job_1"]["application"] == "DaVinci/v45r3"
-    assert data["job_1"]["input"] == {"bk_query": "/some/query"}
+    assert data["job_1"]["input"] == {
+        "bk_query": "/MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
+    }
     assert data["job_1"]["output"] == "FILETYPE.ROOT"
     assert data["job_1"]["options"] == ["options.py"]
     assert data["job_1"]["wg"] == "Charm"
@@ -280,7 +294,9 @@ def test_good_some_turbo():
     assert data["job_1"]["inform"] == ["name@example.com"]
 
     assert data["job_2"]["application"] == "DaVinci/v44r0"
-    assert data["job_2"]["input"] == {"bk_query": "/some/other/query"}
+    assert data["job_2"]["input"] == {
+        "bk_query": "/MC/2018/Beam6500GeV-2018-MagUp/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
+    }
     assert data["job_2"]["output"] == "FILETYPE.ROOT"
     assert data["job_2"]["options"] == ["other_options.py"]
     assert data["job_2"]["wg"] == "B2OC"
@@ -289,7 +305,9 @@ def test_good_some_turbo():
     assert data["job_2"]["inform"] == ["other@example.com"]
 
     assert data["job_3"]["application"] == "DaVinci/v45r3"
-    assert data["job_3"]["input"] == {"bk_query": "/some/query"}
+    assert data["job_3"]["input"] == {
+        "bk_query": "/MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
+    }
     assert data["job_3"]["output"] == "FILETYPE.ROOT"
     assert data["job_3"]["options"] == ["options.py"]
     assert data["job_3"]["wg"] == "Charm"
@@ -315,7 +333,7 @@ def test_good_automatically_configure_overrides():
     job_1:
         application: DaVinci/v45r3
         input:
-            bk_query: "/some/query"
+            bk_query: "/MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
         output: FILETYPE.ROOT
         options:
             - options.py
@@ -323,7 +341,7 @@ def test_good_automatically_configure_overrides():
     job_2:
         application: DaVinci/v44r0
         input:
-            bk_query: "/some/other/query"
+            bk_query: "/MC/2018/Beam6500GeV-2018-MagUp/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
         output: FILETYPE.ROOT
         options:
             - other_options.py
@@ -335,7 +353,7 @@ def test_good_automatically_configure_overrides():
     job_3:
         application: DaVinci/v45r3
         input:
-            bk_query: "/some/query"
+            bk_query: "/MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
         output: FILETYPE.ROOT
         turbo: yes
         options:
@@ -353,7 +371,9 @@ def test_good_automatically_configure_overrides():
     assert len(data) == 3
 
     assert data["job_1"]["application"] == "DaVinci/v45r3"
-    assert data["job_1"]["input"] == {"bk_query": "/some/query"}
+    assert data["job_1"]["input"] == {
+        "bk_query": "/MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
+    }
     assert data["job_1"]["output"] == "FILETYPE.ROOT"
     assert data["job_1"]["options"] == ["options.py"]
     assert data["job_1"]["wg"] == "Charm"
@@ -364,7 +384,9 @@ def test_good_automatically_configure_overrides():
         assert key not in data["job_1"]
 
     assert data["job_2"]["application"] == "DaVinci/v44r0"
-    assert data["job_2"]["input"] == {"bk_query": "/some/other/query"}
+    assert data["job_2"]["input"] == {
+        "bk_query": "/MC/2018/Beam6500GeV-2018-MagUp/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
+    }
     assert data["job_2"]["output"] == "FILETYPE.ROOT"
     assert data["job_2"]["options"] == ["other_options.py"]
     assert data["job_2"]["wg"] == "B2OC"
@@ -373,7 +395,9 @@ def test_good_automatically_configure_overrides():
     assert data["job_2"]["inform"] == ["other@example.com"]
 
     assert data["job_3"]["application"] == "DaVinci/v45r3"
-    assert data["job_3"]["input"] == {"bk_query": "/some/query"}
+    assert data["job_3"]["input"] == {
+        "bk_query": "/MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
+    }
     assert data["job_3"]["output"] == "FILETYPE.ROOT"
     assert data["job_3"]["options"] == ["options.py"]
     assert data["job_3"]["wg"] == "Charm"
@@ -410,7 +434,7 @@ def test_good_automatically_configure_defaults_overrides():
     job_1:
         application: DaVinci/v45r3
         input:
-            bk_query: "/some/query"
+            bk_query: "/MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
         output: FILETYPE.ROOT
         options:
             - options.py
@@ -418,7 +442,7 @@ def test_good_automatically_configure_defaults_overrides():
     job_2:
         application: DaVinci/v44r0
         input:
-            bk_query: "/some/other/query"
+            bk_query: "/MC/2018/Beam6500GeV-2018-MagUp/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
         output: FILETYPE.ROOT
         options:
             - other_options.py
@@ -430,7 +454,7 @@ def test_good_automatically_configure_defaults_overrides():
     job_3:
         application: DaVinci/v45r3
         input:
-            bk_query: "/some/query"
+            bk_query: "/MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
         output: FILETYPE.ROOT
         turbo: yes
         options:
@@ -448,7 +472,9 @@ def test_good_automatically_configure_defaults_overrides():
     assert len(data) == 3
 
     assert data["job_1"]["application"] == "DaVinci/v45r3"
-    assert data["job_1"]["input"] == {"bk_query": "/some/query"}
+    assert data["job_1"]["input"] == {
+        "bk_query": "/MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
+    }
     assert data["job_1"]["output"] == "FILETYPE.ROOT"
     assert data["job_1"]["options"] == ["options.py"]
     assert data["job_1"]["wg"] == "Charm"
@@ -457,7 +483,9 @@ def test_good_automatically_configure_defaults_overrides():
     assert data["job_1"]["inform"] == ["name@example.com"]
 
     assert data["job_2"]["application"] == "DaVinci/v44r0"
-    assert data["job_2"]["input"] == {"bk_query": "/some/other/query"}
+    assert data["job_2"]["input"] == {
+        "bk_query": "/MC/2018/Beam6500GeV-2018-MagUp/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
+    }
     assert data["job_2"]["output"] == "FILETYPE.ROOT"
     assert data["job_2"]["options"] == ["other_options.py"]
     assert data["job_2"]["wg"] == "B2OC"
@@ -475,7 +503,9 @@ def test_good_automatically_configure_defaults_overrides():
         assert data[job]["conddb_tag"] == "abc-def-20u"
 
     assert data["job_3"]["application"] == "DaVinci/v45r3"
-    assert data["job_3"]["input"] == {"bk_query": "/some/query"}
+    assert data["job_3"]["input"] == {
+        "bk_query": "/MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
+    }
     assert data["job_3"]["output"] == "FILETYPE.ROOT"
     assert data["job_3"]["options"] == ["options.py"]
     assert data["job_3"]["wg"] == "Charm"
@@ -499,7 +529,9 @@ def test_bad_missing_key(missing_key):
     data = {
         "job_1": {
             "application": "DaVinci/v45r3",
-            "input": {"bk_query": "/some/query"},
+            "input": {
+                "bk_query": "/MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
+            },
             "output": "FILETYPE.ROOT",
             "options": ["options.py"],
             "wg": "Charm",
@@ -537,7 +569,9 @@ def test_bad_invalid_value(key, value):
     data = {
         "job_1": {
             "application": "DaVinci/v45r3",
-            "input": {"bk_query": "/some/query"},
+            "input": {
+                "bk_query": "/MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
+            },
             "output": "FILETYPE.ROOT",
             "options": ["options.py"],
             "wg": "Charm",
@@ -548,3 +582,38 @@ def test_bad_invalid_value(key, value):
     rendered_yaml = strictyaml.YAML(data).as_yaml()
     with pytest.raises(strictyaml.YAMLValidationError, match=key + ":"):
         LbAPCommon.parse_yaml(rendered_yaml)
+
+
+def test_filetype_validation():
+    from LbAPCommon.parsing import _normalise_filetype
+
+    with pytest.raises(ValueError) as excinfo:
+        _normalise_filetype("PROD", "JOB", "XICPS_MC_26265072_2016_MAGUP.ROOT")
+    assert "is excessively long" not in str(excinfo.value)
+    assert "event type" in str(excinfo.value)
+    assert "magnet polarity" in str(excinfo.value)
+    assert "data taking year" in str(excinfo.value)
+
+    with pytest.raises(ValueError) as excinfo:
+        _normalise_filetype("PROD", "JOB", "XICPS_MC_26265072.ROOT")
+    assert "is excessively long" not in str(excinfo.value)
+    assert "event type" in str(excinfo.value)
+    assert "magnet polarity" not in str(excinfo.value)
+    assert "data taking year" not in str(excinfo.value)
+
+    with pytest.raises(ValueError) as excinfo:
+        _normalise_filetype("PROD", "JOB", "XICPS_MC_MagDown.ROOT")
+    assert "is excessively long" not in str(excinfo.value)
+    assert "event type" not in str(excinfo.value)
+    assert "magnet polarity" in str(excinfo.value)
+    assert "data taking year" not in str(excinfo.value)
+
+    with pytest.raises(ValueError) as excinfo:
+        _normalise_filetype("PROD", "JOB", "A" * 100)
+    assert "is excessively long" in str(excinfo.value)
+    assert "event type" not in str(excinfo.value)
+    assert "magnet polarity" not in str(excinfo.value)
+    assert "data taking year" not in str(excinfo.value)
+
+    assert _normalise_filetype("PROD", "JOB", "XICPS_MC.ROOT") == "XICPS_MC.ROOT"
+    assert _normalise_filetype("PROD", "JOB", "xicps_mc.root") == "XICPS_MC.ROOT"
